OC.L10N.register(
    "photos",
    {
    "Photos" : "照片",
    "Your memories under your control" : "您的回忆在您的掌控之下",
    "Videos" : "视频",
    "Albums" : "专辑",
    "People" : "人物",
    "Folders" : "文件夹",
    "Favorites" : "收藏",
    "On this day" : "当年今日",
    "Shared with you" : "已与您共享",
    "Tags" : "标签",
    "Locations" : "地点",
    "Back" : "返回",
    "Save" : "保存",
    "Open the full size \"{name}\" image" : "打开图片 “{name}” 的完整尺寸",
    "Upload from computer" : "从电脑上传",
    "Open the \"{name}\" sub-directory" : "打开 “{name}” 的子目录",
    "Back to {folder}" : "返回 {folder}",
    "Share this folder" : "共享此文件夹",
    "_{years} year ago_::_{years} years ago_" : ["{years} 年前"],
    "Enable squared photos view" : "启用平铺照片视图",
    "View" : "查看",
    "An error occurred" : "发生错误",
    "Favorite" : "收藏",
    "Remove from favorites" : "从收藏中移除",
    "This folder does not exist" : "此文件夹不存在",
    "No photos in here" : "这里没有照片",
    "No tags yet" : "尚无标签",
    "Photos with tags will show up here" : "带标签的照片将显示在此处",
    "Add" : "添加",
    "Download" : "下载",
    "Delete selection" : "删除选择项",
    "Delete" : "删除",
    "Tagged photos" : "标记的照片",
    "Your photos" : "你的照片",
    "Your videos" : "您的视频",
    "Your folders" : "您的文件夹",
    "Settings" : "设置"
},
"nplurals=1; plural=0;");
